# <img src="https://i.imgur.com/nPCcxts.png" height="25" style="height: 25px"> mcproto

[![discord chat](https://img.shields.io/discord/936788458939224094.svg?logo=Discord)](https://discord.gg/C2wX7zduxC)
![supported python versions](https://img.shields.io/pypi/pyversions/mcproto.svg)
[![current PyPI version](https://img.shields.io/pypi/v/mcproto.svg)](https://pypi.org/project/mcproto/)
[![CI](https://github.com/py-mine/mcproto/actions/workflows/main.yml/badge.svg)](https://github.com/py-mine/mcproto/actions/workflows/main.yml)
[![Docs](https://github.com/py-mine/mcproto/actions/workflows/docs.yml/badge.svg)](https://github.com/py-mine/mcproto/actions/workflows/docs.yml)

Mcproto is a python library that provides various low level interactions with the Minecraft protocol. It attempts to be
a full wrapper around the Minecraft protocol, which means it could be used as a basis for Minecraft bots written in
python, or even full python server implementations.

> [!WARNING]
> Currently, the library is still work in progress and very incomplete, so while contributions are welcome, fair warning
> that using mcproto in production isn't recommended.

For more info, check our [documentation](https://py-mine.github.io/mcproto).
